==========
Change Log
==========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_ and this project adheres to `Semantic Versioning`_.

.. _`Keep a Changelog`: http://keepachangelog.com/
.. _`Semantic Versioning`: http://semver.org/


0.1.0_ -- 2018-04-02
--------------------

Added
~~~~~

- Add basic functions.


.. _Unreleased: https://github.com/zaufi/https://github.com/zaufi/trivial-yaml-config/release/0.1.0...HEAD
.. _0.1.0: https://github.com/zaufi/trivial-yaml-config/releases/tag/release%2F0.1.0
